Re-exports
pub use occt::edge::Edge;pub use occt::face::Face;pub use occt::solid::Solid;pub use common::color::Color;pub use common::error::Error;pub use common::mesh::EdgeData;pub use common::mesh::Mesh;pub use glam;
Modules
Structs
- DMat3
- A 3x3 column major matrix.
- DMat4
- A 4x4 column major matrix.
- DQuat
- A quaternion representing an orientation.
- DVec2
- A 2-dimensional vector.
- DVec3
- A 3-dimensional vector.
Enums
- BSpline
End - End-condition selector for [
EdgeStruct::bspline]. - Profile
Orient - Controls how the cross-section profile is oriented as it travels along the
spine in [
SolidStruct::sweep] and [SolidStruct::sweep_sections].
Traits
- Compound
- Public trait: solid-specific operations on Solid, Vec
, and [Solid; N]. - Wire
- Public trait: edge/wire-level operations on
Edge,Vec<Edge>and[Edge; N].
Functions
- is_
shape_ face - Check if a face came from the shape (a-side) of a boolean operation.
- is_
tool_ face - Check if a face came from the tool (b-side) of a boolean operation.
- mesh
- read_
brep_ binary - read_
brep_ text - read_
step - write_
brep_ binary - write_
brep_ text - write_
step